@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.1200';
+our $VERSION = '0.1201';
 
 use MIDI::Simple;
 use Moo;
@@ -105,6 +105,16 @@ has dotted_sixteenth  => ( is => 'ro', default => sub { 'dsn' } );
 sub note { return shift->score->n(@_) }
 
 
+sub accent_note {
+    my $self = shift;
+    my $accent = shift;
+    my $resume = $self->score->Volume;
+    $self->score->Volume($accent);
+    $self->note(@_);
+    $self->score->Volume($resume);
+}
+
+
 sub rest { return shift->score->r(@_) }
 
 
@@ -117,9 +127,19 @@ sub count_in {
 }
 
 
-sub metronome44 { shift->metronome(@_) }
+sub metronome34 {
+    my $self = shift;
+    my $bars = shift || $self->bars;
 
-sub metronome {
+    for ( 1 .. $bars ) {
+        $self->note( $self->quarter, $self->ride1, $self->kick );
+        $self->note( $self->quarter, $self->ride1 );
+        $self->note( $self->quarter, $self->ride1, $self->snare );
+    }
+}
+
+
+sub metronome44 {
     my $self = shift;
     my $bars = shift || $self->bars;
     my $flag = shift || 0;
@@ -155,18 +175,6 @@ sub metronome {
 }
 
 
-sub metronome34 {
-    my $self = shift;
-    my $bars = shift || $self->bars;
-
-    for ( 1 .. $bars ) {
-        $self->note( $self->quarter, $self->ride1, $self->kick );
-        $self->note( $self->quarter, $self->ride1 );
-        $self->note( $self->quarter, $self->ride1, $self->snare );
-    }
-}
-
-
 sub metronome54 {
     my $self = shift;
     my $bars = shift || $self->bars;
@@ -264,15 +272,6 @@ sub set_time_sig {
 }
 
 
-sub accent_note {
-    my $self = shift;
-    my $volume = shift;
-    $self->score->Volume($volume->[0]);
-    $self->note(@_);
-    $self->score->Volume($volume->[1]);
-}
-
-
 sub write {
     my $self = shift;
     $self->score->write_score( $self->file );
@@ -292,7 +291,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.1200
+version 0.1201
 
 =head1 SYNOPSIS
 
@@ -427,7 +426,17 @@ Return a new C<MIDI::Drummer::Tiny> object.
 
 Add a note to the score.
 
-This method takes the same arguments as with L<MIDI::Simple/"Parameters for n/r/noop">.
+This method takes the same arguments as L<MIDI::Simple/"Parameters for n/r/noop">.
+
+=head2 accent_note
+
+  $d->accent_note($accent_value, $d->sixteenth, $d->snare);
+
+Play an accented note.
+
+For instance, this can be a "ghosted note", where the B<accent> is a
+smaller number (< 50).  Or a note that is greater than the normal
+score volume.
 
 =head2 rest
 
@@ -435,7 +444,7 @@ This method takes the same arguments as with L<MIDI::Simple/"Parameters for n/r/
 
 Add a rest to the score.
 
-This method takes the same arguments as with L<MIDI::Simple/"Parameters for n/r/noop">.
+This method takes the same arguments as L<MIDI::Simple/"Parameters for n/r/noop">.
 
 =head2 count_in
 
@@ -445,7 +454,14 @@ This method takes the same arguments as with L<MIDI::Simple/"Parameters for n/r/
 Play the closed hihat for the number of beats times the given bars.
 If no bars are given, the default times the number of beats is used.
 
-=head2 metronome, metronome44
+=head2 metronome34
+
+  $d->metronome34;
+  $d->metronome34($bars);
+
+Add a steady 3/4 beat to the score.
+
+=head2 metronome44
 
   $d->metronome44;
   $d->metronome44($bars);
@@ -458,13 +474,6 @@ Add a steady 4/4 beat to the score.
 If a B<flag> is provided the beat is modified to include alternating
 eighth-note kicks.
 
-=head2 metronome34
-
-  $d->metronome34;
-  $d->metronome34($bars);
-
-Add a steady 3/4 beat to the score.
-
 =head2 metronome54
 
   $d->metronome54;
@@ -507,16 +516,6 @@ Add a 7/8 beat to the score.
 Set the B<signature>, B<beats>, B<divisions>, and the B<score>
 C<time_signature> values based on the given string.
 
-=head2 accent_note
-
-  $d->accent_note([$accent, $resume], $d->sixteenth, $d->snare);
-
-Play an accented note.
-
-For instance, this can be a "ghosted note", where the B<accent> is a
-smaller number (< 50).  Or a note that is greater than the current
-(B<resume>) volume.
-
 =head2 write
 
 Output the score to the default F<*.mid> file or one given to the
